==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualGatewayResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * A collection of values returned by getVirtualGateway.
 * @property arn ARN of the virtual gateway.
 * @property createdDate Creation date of the virtual gateway.
 * @property id The provider-assigned unique ID for this managed resource.
 * @property lastUpdatedDate Last update date of the virtual gateway.
 * @property meshName
 * @property meshOwner
 * @property name
 * @property resourceOwner Resource owner's AWS account ID.
 * @property specs Virtual gateway specification. See the `aws.appmesh.VirtualGateway` resource for details.
 * @property tags Map of tags.
 */
public data class GetVirtualGatewayResult(
    public val arn: String,
    public val createdDate: String,
    public val id: String,
    public val lastUpdatedDate: String,
    public val meshName: String,
    public val meshOwner: String,
    public val name: String,
    public val resourceOwner: String,
    public val specs: List<GetVirtualGatewaySpec>,
    public val tags: Map<String, String>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualGatewayResult):
            GetVirtualGatewayResult = GetVirtualGatewayResult(
            arn = javaType.arn(),
            createdDate = javaType.createdDate(),
            id = javaType.id(),
            lastUpdatedDate = javaType.lastUpdatedDate(),
            meshName = javaType.meshName(),
            meshOwner = javaType.meshOwner(),
            name = javaType.name(),
            resourceOwner = javaType.resourceOwner(),
            specs = javaType.specs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpec.Companion.toKotlin(args0)
                })
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualGatewayResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * A collection of values returned by getVirtualGateway.
 * @property arn ARN of the virtual gateway.
 * @property createdDate Creation date of the virtual gateway.
 * @property id The provider-assigned unique ID for this managed resource.
 * @property lastUpdatedDate Last update date of the virtual gateway.
 * @property meshName
 * @property meshOwner
 * @property name
 * @property resourceOwner Resource owner's AWS account ID.
 * @property specs Virtual gateway specification. See the `aws.appmesh.VirtualGateway` resource for details.
 * @property tags Map of tags.
 */
public data class GetVirtualGatewayResult(
    public val arn: String,
    public val createdDate: String,
    public val id: String,
    public val lastUpdatedDate: String,
    public val meshName: String,
    public val meshOwner: String,
    public val name: String,
    public val resourceOwner: String,
    public val specs: List<GetVirtualGatewaySpec>,
    public val tags: Map<String, String>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualGatewayResult): GetVirtualGatewayResult = GetVirtualGatewayResult(
            arn = javaType.arn(),
            createdDate = javaType.createdDate(),
            id = javaType.id(),
            lastUpdatedDate = javaType.lastUpdatedDate(),
            meshName = javaType.meshName(),
            meshOwner = javaType.meshOwner(),
            name = javaType.name(),
            resourceOwner = javaType.resourceOwner(),
            specs = javaType.specs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpec.Companion.toKotlin(args0)
                })
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
        )
    }
}
